<?php
namespace Bushelpowered\Api\Aggregator\Crm\V1\Response;
        
class BinResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $customerId The UUID of the customer associated with the bin*/
    public string $customerId;
    /** @var string $commoditySubgroupId The commodity subgroup id from Commodity Service*/
    public string $commoditySubgroupId;
    /** @var string $commodityName The name of the commodity name, made up of the subgroup and group. ei Yellow Corn*/
    public string $commodityName;
    /** @var null|string $commodityVarietyId The commodity variety id from Commodity Service, nullable*/
    public ?string $commodityVarietyId = null;
    /** @var null|string $commodityVarietyName The name of the commodity variety*/
    public ?string $commodityVarietyName = null;
    /** @var string $name The name of the bin*/
    public string $name;
    /** @var null|int $quantity The quantity in the bin, nullable*/
    public ?int $quantity = null;
    /** @var string $quantityUoM Unit of measure for quantity, default to bu*/
    public string $quantityUoM;
    /** @var string $comments Comments about the bin*/
    public string $comments;
    /** @var null|float $protein The protein of the commodity in the bin, nullable*/
    public ?float $protein = null;
    /** @var null|float $testWeight The test weight of the commodity in the bin, nullable*/
    public ?float $testWeight = null;
    /** @var null|float $moisture The moisture content of the commodity in the bin, nullable*/
    public ?float $moisture = null;
    /** @var null|float $dhv The dhv of the commodity in the bin, nullable*/
    public ?float $dhv = null;
    /** @var null|float $hvac The hvac of the commodity in the bin, nullable*/
    public ?float $hvac = null;
    /** @var null|float $plump The plump of the commodity in the bin, nullable*/
    public ?float $plump = null;
    /** @var null|float $thins The thins of the commodity in the bin, nullable*/
    public ?float $thins = null;
    /** @var null|float $skbn The skbn of the commodity in the bin, nullable*/
    public ?float $skbn = null;
    /** @var string $createdBy The name of the user that created the bin*/
    public string $createdBy;
    /** @var string $updatedBy The name of the user that updated the bin*/
    public string $updatedBy;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $customerId The UUID of the customer associated with the bin
     * @param  string  $commoditySubgroupId The commodity subgroup id from Commodity Service
     * @param  string  $commodityName The name of the commodity name, made up of the subgroup and group. ei Yellow Corn
     * @param  null|string  $commodityVarietyId The commodity variety id from Commodity Service, nullable
     * @param  null|string  $commodityVarietyName The name of the commodity variety
     * @param  string  $name The name of the bin
     * @param  null|int  $quantity The quantity in the bin, nullable
     * @param  string  $quantityUoM Unit of measure for quantity, default to bu
     * @param  string  $comments Comments about the bin
     * @param  null|float  $protein The protein of the commodity in the bin, nullable
     * @param  null|float  $testWeight The test weight of the commodity in the bin, nullable
     * @param  null|float  $moisture The moisture content of the commodity in the bin, nullable
     * @param  null|float  $dhv The dhv of the commodity in the bin, nullable
     * @param  null|float  $hvac The hvac of the commodity in the bin, nullable
     * @param  null|float  $plump The plump of the commodity in the bin, nullable
     * @param  null|float  $thins The thins of the commodity in the bin, nullable
     * @param  null|float  $skbn The skbn of the commodity in the bin, nullable
     * @param  string  $createdBy The name of the user that created the bin
     * @param  string  $updatedBy The name of the user that updated the bin
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $tenantId, string $customerId, string $commoditySubgroupId, string $commodityName, ?string $commodityVarietyId, ?string $commodityVarietyName, string $name, ?int $quantity, string $quantityUoM, string $comments, ?float $protein, ?float $testWeight, ?float $moisture, ?float $dhv, ?float $hvac, ?float $plump, ?float $thins, ?float $skbn, string $createdBy, string $updatedBy, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->tenantId = $tenantId;
        $this->customerId = $customerId;
        $this->commoditySubgroupId = $commoditySubgroupId;
        $this->commodityName = $commodityName;
        $this->commodityVarietyId = $commodityVarietyId;
        $this->commodityVarietyName = $commodityVarietyName;
        $this->name = $name;
        $this->quantity = $quantity;
        $this->quantityUoM = $quantityUoM;
        $this->comments = $comments;
        $this->protein = $protein;
        $this->testWeight = $testWeight;
        $this->moisture = $moisture;
        $this->dhv = $dhv;
        $this->hvac = $hvac;
        $this->plump = $plump;
        $this->thins = $thins;
        $this->skbn = $skbn;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}